@@ -1147,12 +1147,12 @@ void Channel::modeButtonClicked(int id, bool on)
     {
         if (args.isEmpty())
         {
-            TQCString newPassword;
+            TQString newPassword;
 
             int result = KPasswordDialog::getPassword(newPassword, i18n("Channel Password"));
 
             if (result == KPasswordDialog::Accepted && !newPassword.isEmpty())
-                args = newPassword;
+                args = newPassword.utf8();
         }
 
     }
