@@ -31,14 +31,14 @@
 #include <tqwhatsthis.h>
 
 #include <krun.h>
-#include <klistview.h>
+#include <tdelistview.h>
 #include <klineedit.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
-#include <kfiledialog.h>
-#include <kmessagebox.h>
-#include <kpopupmenu.h>
-#include <kdeversion.h>
+#include <tdefiledialog.h>
+#include <tdemessagebox.h>
+#include <tdepopupmenu.h>
+#include <tdeversion.h>
 
 
 ChannelListPanel::ChannelListPanel(TQWidget* parent) : ChatWindow(parent)
@@ -101,13 +101,13 @@ ChannelListPanel::ChannelListPanel(TQWidget* parent) : ChatWindow(parent)
 
     targetBox->setStretchFactor(topicFilter,10);
 
-    channelListView=new KListView(this,"channel_list_view");
+    channelListView=new TDEListView(this,"channel_list_view");
     TQWhatsThis::add(channelListView, i18n("The filtered list of channels is displayed here. Notice that if you do not use regular expressions, Konversation lists any channel whose name contains the filter string you entered. The channel name does not have to start with the string you entered.\n\nSelect a channel you want to join by clicking on it. Right click on the channel to get a list of all web addresses mentioned in the channel's topic."));
     channelListView->addColumn(i18n("Channel Name"));
     channelListView->addColumn(i18n("Users"));
     channelListView->addColumn(i18n("Channel Topic"));
     channelListView->setAllColumnsShowFocus(true);
-    channelListView->setResizeMode( KListView::LastColumn );
+    channelListView->setResizeMode( TDEListView::LastColumn );
     channelListView->setSortColumn(-1); //Disable sorting
 
     TQHBox* statsBox=new TQHBox(this);
@@ -132,8 +132,8 @@ ChannelListPanel::ChannelListPanel(TQWidget* parent) : ChatWindow(parent)
     connect(channelListView,TQT_SIGNAL (doubleClicked(TQListViewItem*)),
         this,TQT_SLOT (joinChannelClicked()) );
 
-    connect(channelListView,TQT_SIGNAL (contextMenu (KListView*, TQListViewItem*, const TQPoint&) ),
-        this, TQT_SLOT (contextMenu (KListView*, TQListViewItem*, const TQPoint&)) );
+    connect(channelListView,TQT_SIGNAL (contextMenu (TDEListView*, TQListViewItem*, const TQPoint&) ),
+        this, TQT_SLOT (contextMenu (TDEListView*, TQListViewItem*, const TQPoint&)) );
 
     connect(minUsersSpin,TQT_SIGNAL (valueChanged(int)),this,TQT_SLOT(setMinUsers(int)) );
     connect(maxUsersSpin,TQT_SIGNAL (valueChanged(int)),this,TQT_SLOT(setMaxUsers(int)) );
@@ -498,11 +498,11 @@ void ChannelListPanel::childAdjustFocus()
 {
 }
 
-void ChannelListPanel::contextMenu (KListView* /* l */, TQListViewItem* i, const TQPoint& p)
+void ChannelListPanel::contextMenu (TDEListView* /* l */, TQListViewItem* i, const TQPoint& p)
 {
     if(!i) return;
 
-    KPopupMenu* showURLmenu = new KPopupMenu(this);
+    TDEPopupMenu* showURLmenu = new TDEPopupMenu(this);
     showURLmenu->insertTitle( i18n("Open URL") );
     TQString filteredLine(i->text(2));
 
