@@ -17,16 +17,16 @@
 
 #include "chatwindow.h"
 
-#include <kio/job.h>
+#include <tdeio/job.h>
 
 
-class KToolBar;
+class TDEToolBar;
 class TQSpinBox;
 
 class LogfileReader : public ChatWindow
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 
         public:
         LogfileReader(TQWidget* parent, const TQString& log);
@@ -43,7 +43,7 @@ class LogfileReader : public ChatWindow
         void clearLog();
         void saveLog();
         void closeLog();
-        void copyResult(KIO::Job* job);
+        void copyResult(TDEIO::Job* job);
 
 
     protected:
@@ -53,7 +53,7 @@ class LogfileReader : public ChatWindow
         /** Called from ChatWindow adjustFocus */
         virtual void childAdjustFocus();
 
-        KToolBar* toolBar;
+        TDEToolBar* toolBar;
         TQSpinBox* sizeSpin;
         TQString fileName;
 };
