@@ -32,13 +32,13 @@
 #include <tqwhatsthis.h>
 #include <tqsplitter.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstandarddirs.h>
 #include <kdebug.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kiconloader.h>
 #include <kstringhandler.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 
 
 Query::Query(TQWidget* parent, TQString _name) : ChatWindow(parent)
@@ -65,7 +65,7 @@ Query::Query(TQWidget* parent, TQString _name) : ChatWindow(parent)
 
     queryHostmask=new Konversation::TopicLabel(box, "query_hostmask");
 
-    TQString whatsthis = i18n("<qt>Some details of the person you are talking to in this query is shown in this bar.  The full name and hostmask is shown, along with any image or logo this person has associated with them in the KDE Addressbook.<p>See the <i>Konversation Handbook</i> for information on associating a nick with a contact in the Addressbook, and for an explanation of what the hostmask is.</qt>");
+    TQString whatsthis = i18n("<qt>Some details of the person you are talking to in this query is shown in this bar.  The full name and hostmask is shown, along with any image or logo this person has associated with them in the TDE Addressbook.<p>See the <i>Konversation Handbook</i> for information on associating a nick with a contact in the Addressbook, and for an explanation of what the hostmask is.</qt>");
     TQWhatsThis::add(addresseeimage, whatsthis);
     TQWhatsThis::add(addresseelogoimage, whatsthis);
     TQWhatsThis::add(queryHostmask, whatsthis);
@@ -102,7 +102,7 @@ Query::Query(TQWidget* parent, TQString _name) : ChatWindow(parent)
     awayLabel->hide();
     blowfishLabel = new TQLabel(inputBox);
     blowfishLabel->hide();
-    blowfishLabel->setPixmap(KGlobal::iconLoader()->loadIcon("encrypted", KIcon::Toolbar));
+    blowfishLabel->setPixmap(TDEGlobal::iconLoader()->loadIcon("encrypted", TDEIcon::Toolbar));
     queryInput=new IRCInput(inputBox);
 
     getTextView()->installEventFilter(queryInput);
@@ -312,8 +312,8 @@ void Query::updateAppearance()
     }
     else
     {
-        getTextView()->setFont(KGlobalSettings::generalFont());
-        queryInput->setFont(KGlobalSettings::generalFont());
+        getTextView()->setFont(TDEGlobalSettings::generalFont());
+        queryInput->setFont(TDEGlobalSettings::generalFont());
     }
 
     ChatWindow::updateAppearance();
@@ -490,7 +490,7 @@ void Query::nickInfoChanged()
             text += " (" + KStringHandler::rsqueeze(m_nickInfo->getAwayMessage(),100) + ") ";
         queryHostmask->setText(Konversation::removeIrcMarkup(text));
 
-        KABC::Picture pic = m_nickInfo->getAddressee().photo();
+        TDEABC::Picture pic = m_nickInfo->getAddressee().photo();
         if(pic.isIntern())
         {
             TQPixmap qpixmap(pic.data().scaleHeight(queryHostmask->height()));
@@ -508,7 +508,7 @@ void Query::nickInfoChanged()
         {
             addresseeimage->hide();
         }
-        KABC::Picture logo = m_nickInfo->getAddressee().logo();
+        TDEABC::Picture logo = m_nickInfo->getAddressee().logo();
         if(logo.isIntern())
         {
             TQPixmap qpixmap(logo.data().scaleHeight(queryHostmask->height()));
