@@ -11,7 +11,6 @@
 */
 
 #include "serverlistdialog.h"
-#include "preferences.h"
 #include "konversationapplication.h"
 #include "servergroupdialog.h"
 #include "connectionsettings.h"
@@ -24,10 +23,10 @@
 #include <tqheader.h>
 #include <tqcheckbox.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
 #include <kguiitem.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 
 
 namespace Konversation
@@ -36,9 +35,9 @@ namespace Konversation
     // ServerListItem
     //
 
-    ServerListItem::ServerListItem(KListView* parent, int serverGroupId, int sortIndex,
+    ServerListItem::ServerListItem(TDEListView* parent, int serverGroupId, int sortIndex,
         const TQString& serverGroup, const TQString& identity, const TQString& channels)
-        : KListViewItem(parent, serverGroup, identity, channels)
+        : TDEListViewItem(parent, serverGroup, identity, channels)
     {
         m_serverGroupId = serverGroupId;
         m_sortIndex = sortIndex;
@@ -48,7 +47,7 @@ namespace Konversation
 
     ServerListItem::ServerListItem(TQListViewItem* parent, int serverGroupId, int sortIndex,
         const TQString& name, const ServerSettings& server)
-        : KListViewItem(parent, name)
+        : TDEListViewItem(parent, name)
     {
         m_serverGroupId = serverGroupId;
         m_sortIndex = sortIndex;
@@ -109,14 +108,14 @@ namespace Konversation
         TQFrame* mainWidget = plainPage();
 
         m_serverList = new ServerListView(mainWidget);
-        TQWhatsThis::add(m_serverList, i18n("This shows the listof configured IRC networks. An IRC network is a collection of cooperating servers. You need only connect to one of the servers in the network to be connected to the entire IRC network. Once connected, Konversation will automatically join the channels shown. When Konversation is started for the first time, the Freenode network and the <i>#kde</i> channel are already entered for you."));
+        TQWhatsThis::add(m_serverList, i18n("This shows the list of configured IRC networks. An IRC network is a collection of cooperating servers. You need only connect to one of the servers in the network to be connected to the entire IRC network. Once connected, Konversation will automatically join the channels shown. When Konversation is started for the first time, the Freenode network and the <i>#trinity-desktop</i> channel are already entered for you."));
         m_serverList->setAllColumnsShowFocus(true);
         m_serverList->setRootIsDecorated(true);
         m_serverList->setResizeMode(TQListView::AllColumns);
         m_serverList->addColumn(i18n("Network"));
         m_serverList->addColumn(i18n("Identity"));
         m_serverList->addColumn(i18n("Channels"));
-        m_serverList->setSelectionModeExt(KListView::Extended);
+        m_serverList->setSelectionModeExt(TDEListView::Extended);
         m_serverList->setShowSortIndicator(true);
         m_serverList->setSortColumn(0);
         m_serverList->setDragEnabled(true);
@@ -162,7 +161,7 @@ namespace Konversation
 
         updateButtons();
 
-        KConfig* config = kapp->config();
+        TDEConfig* config = kapp->config();
         config->setGroup("ServerListDialog");
         TQSize newSize = size();
         newSize = config->readSizeEntry("Size", &newSize);
@@ -173,7 +172,7 @@ namespace Konversation
 
     ServerListDialog::~ServerListDialog()
     {
-        KConfig* config = kapp->config();
+        TDEConfig* config = kapp->config();
         config->setGroup("ServerListDialog");
         config->writeEntry("Size", size());
     }
