@@ -16,13 +16,13 @@
 #include "warnings_preferencesui.h"
 #include "konvisettingspage.h"
 
-class KListView;
+class TDEListView;
 class TQListViewItem;
 
 class Warnings_Config : public Warnings_ConfigUI, public KonviSettingsPage
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 
     public:
         explicit Warnings_Config( TQWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
